import os
#
#     Setting up a variable to specify the location of your final images
#     makes your script easier to read and more portable when you share it
#     with other users
#

homePath=expandpath('~')
dataPath=os.path.join(homePath, 'Data')
scriptingPath=os.path.join(dataPath, 'Scripting')

enhancementPath=os.path.join(scriptingPath, 'Color-Enhancements')

areaPath=os.path.join(scriptingPath,'tornado-areas')
irPath=os.path.join(areaPath,'IR')

#
#   imagePath is the directory to store final images
#   and/or animated gif files
#
imagePath=os.path.join(scriptingPath,'Images')


#
#   This example gets the information from the dataset created previously in the tutorial
#
irLocalDataSet = getLocalADDEEntry('TORNADO','GOES-13 IR')
ADDE_IR_loadRequest = dict(
    debug=True,
    server='localhost',
    localEntry=irLocalDataSet,
    size='ALL',
    time=('23:45:00','23:45:00'),
    day='2011142',
    unit='TEMP',
)

irData=loadADDEImage(**ADDE_IR_loadRequest)

#
#   assign a temperature threshold used with mask() function
#
temperatureThreshold=250.0

#
#   Applying a mask is a two part process.
#   First we assign a value of 1 or missing value to a temporary data object
#   Second, multiply the first results to the temporary data object
#
maskedData=mask(irData, 'lt', temperatureThreshold,1)
finalDataSet=mul(irData, maskedData)
    

#
#   Import enhancement table
#
IRTable=importColorTable(enhancementPath+'/Tornado-IR.xml',overwrite=True)
IRTableName=IRTable.getName()

#
#   Build a window and turn off the wireframe box
#
bwLines = irData['lines'] / 2
bwEles = irData['elements'] / 2
panel = buildWindow(height=bwLines, width=bwEles)
panel[0].setWireframe(False)

#
#   Add layers to the existing window set enhancement table and data ranges
#
irLayer=panel[0].createLayer('Image Display', finalDataSet)
irLayer.setLayerLabel('GOES-13 Temperatures less than ' + str(temperatureThreshold) + ' %timestamp%')
irLayer.setEnhancement(IRTableName, range=(temperatureThreshold,200))


#
#   Set the center latitude, longitude and scale
#
panel[0].setProjection('US>States>N-Z>Oklahoma')
panel[0].setCenter(33, -97, scale=.5)

fileName=os.path.join(imagePath, 'ir-image.gif')
panel[0].captureImage(fileName)