import os
import csv

#     Setting up a variable to specify the location of your final images
#     makes your script easier to read and more portable when you share it
#     with other users
#

homePath=expandpath('~')
dataPath=os.path.join(homePath,'Data')
scriptingPath=os.path.join(dataPath,'Scripting')

enhancementPath=os.path.join(scriptingPath,'Color-Enhancements')
statisticsPath=os.path.join(scriptingPath,'Statistics')

areaPath=os.path.join(scriptingPath,'tornado-areas')
irPath=os.path.join(areaPath,'IR')

#
#   imagePath is the directory to store final images
#   and/or animated gif files
#
imagePath=os.path.join(scriptingPath,'Images')

#
#     The easiest way to make an ADDE request is to create a dictionary
#     That defines your parameters.  Here we have a generic request
# 
irLocalDataSet = getLocalADDEEntry('TORNADO', 'GOES-13 IR')
ADDE_IR_loadRequest = dict(
    server='localhost',
    localEntry=irLocalDataSet,
    place=Places.CENTER,
    size=(100,200),
    coordinateSystem=LATLON,
    location=(37.0,-94.5),
    mag=(1, 1),
    unit='TEMP',
)


textFileName = os.path.join(statisticsPath,"stats.txt")
textOutputFile = open(textFileName, "w") 

csvFileName = os.path.join(statisticsPath,"stats.csv")
csvOutputFile = open(csvFileName, "wb") 

csvData = csv.writer(csvOutputFile, delimiter=",")
csvData.writerow(["Time", "latitude", "longitude", "geometricMean", "min", "median", "max", "kurtosis", "numPoints", "skewness", "stdDev", "variance"])

#
#     Now make the request using the function loadADDEImage
#     This returns an object containing data and metadata
#
for pos in range(-4,1):
    irData = loadADDEImage(position=(pos),band=4, **ADDE_IR_loadRequest)

#
#     pass the irData into the Statistics package
#
    stats=Statistics(irData)

#
#     open a file and write out the statistics data
#
    textOutputFile.write("   stat and value for: %s \n" % irData["nominal-time"])
    textOutputFile.write("   geometric mean: %s \n" % stats.geometricMean())
    textOutputFile.write("   kurtosis: %s \n" % stats.kurtosis())
    textOutputFile.write("   num points: %s \n" % stats.numPoints())
    textOutputFile.write("   skewness: %s \n" % stats.skewness())
    textOutputFile.write("   std dev: %s \n" % stats.standardDeviation())
    textOutputFile.write("   variance: %s \n" % stats.variance())
    textOutputFile.write("\n")

#
#     import the csv library for writing out the 
#     statistics values
#
    theTime = str(irData["nominal-time"])[11:16]
    csvData.writerow([theTime, "37.0", "-94.5", stats.geometricMean(), stats.min(), stats.median(), stats.max(), stats.kurtosis(),
        stats.numPoints(), stats.skewness(), stats.standardDeviation(), stats.variance()])

csvOutputFile.close()
textOutputFile.close()

#
#     The last section of the script will annotate an image
#     with the information from the statistics package.
#
#     Now make the request using the function loadADDEImage.
#     This returns an object containing data and metadata.
#
irData = loadADDEImage(position=-1, band=4, **ADDE_IR_loadRequest)

#
#     pass the irData into the Statistics package for this image
#
statsimage=Statistics(irData) 

#     Create some strings from the data object to be able
#     to annotate our window with the stats values.
#
min = 'min: %s' % (
    statsimage.min()
    )
max = 'max: %s' % (
    statsimage.max()
    )
stddev = 'std dev: %s' % (
    statsimage.standardDeviation()
    )
geomean = 'geometric mean: %s' % (
    statsimage.geometricMean()
    )
numpoints = 'num points: %s' % (
    statsimage.numPoints()
    )

#     Create a string from the data to make it 
#     easier to label the image.
#
irLabel = '%s %s' % (
    irData['sensor-type'],
    irData['nominal-time']
    )

#     
#     Build a window with a single panel 
#
panel = buildWindow(height=600,width=900)

#    
#   Import enhancement table
#
IRTable=importColorTable(enhancementPath+'/Tornado-IR.xml',overwrite=True)
IRTableName=IRTable.getName()

#
#     Create a layer from the infrared data object 
#
irLayer = panel[0].createLayer('Image Display', irData)
irLayer.setEnhancement(IRTableName,range=(250,200))

#
#     When changing attributes, some are panel based and
#     others are layer based.  In the following steps, they are:
# 
#     Change the projection (panel)
#     Turn off the wire frame box (panel)
#     Change the center point (panel)
#     Add the statistics values (panel)
#     Add a layer label (layer)
#     Save the output file (panel)
#
panel[0].setProjection('US>States>N-Z>Oklahoma')
panel[0].setWireframe(False)
panel[0].setCenter(37.0,-94.5, scale=1.0)
panel[0].annotate(min, line=430,element=30, size=18, color='White',alignment=('right','center'))
panel[0].annotate(max, line=460,element=30, size=18, color='White',alignment=('right','center'))
panel[0].annotate(stddev, line=490,element=30, size=18, color='White',alignment=('right','center'))
panel[0].annotate(geomean, line=520,element=30, size=18, color='White',alignment=('right','center'))
panel[0].annotate(numpoints, line=550,element=30, size=18, color='White',alignment=('right','center'))
irLayer.setColorScale(visible=True, placement='Top', showUnit=True, size=20)
irLayer.setLayerLabel(label=irLabel, size=14)
fileName=os.path.join(imagePath,'stats-image.jpg')
panel[0].captureImage(fileName)